@@ -1,8 +1,9 @@
 from django.contrib.auth import get_user_model
 from django.contrib.auth.views import PasswordChangeView, PasswordChangeDoneView
+from django.contrib.messages.views import SuccessMessageMixin
 from django.shortcuts import redirect
 from django.urls import reverse_lazy
-from django.views.generic import DetailView, TemplateView
+from django.views.generic import DetailView
 
 from ddm.auth import user_is_permitted
 from ddm.models import ResearchProfile
@@ -10,9 +11,10 @@ from ddm.models import ResearchProfile
 User = get_user_model()
 
 
-class ProfileDetailView(DetailView):
+class ProfileDetailView(SuccessMessageMixin, DetailView):
     template_name = 'ddm/project_admin/profile/profile_detail.html'
     model = User
+    success_message = 'Profile updated.'
 
     def dispatch(self, request, *args, **kwargs):
         if not request.user.is_authenticated:
@@ -23,7 +25,7 @@ class ProfileDetailView(DetailView):
             return redirect('ddm-register')
         return super().dispatch(request, *args, **kwargs)
 
-    def get_object(self):
+    def get_object(self, queryset=None):
         return self.request.user
 
     def get_context_data(self, **kwargs):
@@ -32,9 +34,10 @@ class ProfileDetailView(DetailView):
         return context
 
 
-class ProfileChangePasswordView(PasswordChangeView):
+class ProfileChangePasswordView(SuccessMessageMixin, PasswordChangeView):
     template_name = 'ddm/project_admin/generic/page_with_form.html'
     success_url = reverse_lazy('ddm-pw-changed')
+    success_message = 'Password changed.'
 
 
 class ProfilePasswordChangedView(PasswordChangeDoneView):
